@@ -16,7 +16,7 @@ After=syslog.target network.target
 
 [Service]
 Type=simple
-ExecStart=$entrypoint --command listen --hostname $hostname --verbose $verbose --port $port --gpio $gpio_number --name $name
+ExecStart=$entrypoint --command listen --hostname $hostname --verbose $verbose --port $port --gpio $gpio --name $name
 SyslogIdentifier=$packagename
 StandardOutput=syslog
 StandardError=syslog
@@ -33,7 +33,7 @@ class PirApp(App):
 
     def do_add_argument(self, parser):
         parser.add_argument('--gpio', metavar='gpio', required=False, type=int, help='the gpio number wired to the device')
-        parser.add_argument('--name', metavar='name', required=False, default='Motion Sensor', type=int, help='the name of the sensor')
+        parser.add_argument('--name', metavar='name', required=False, default='Motion Sensor', type=str, help='the name of the sensor')
 
 
     def do_additional_listen_example_params(self):
@@ -46,7 +46,7 @@ class PirApp(App):
             return True
         elif args.command == 'register' and (args.port > 0):
             print("register " + self.packagename + "/" + args.name  + " on " + hostname + "/" + str(port) + "/gpio " + str(args.gpio) + " and starting it")
-            unit = UNIT_TEMPLATE.substitute(packagename=self.packagename, entrypoint=self.entrypoint, hostname=hostname, port=port, verbose=verbose, gpio_number=args.gpio_number, name=args.name)
+            unit = UNIT_TEMPLATE.substitute(packagename=self.packagename, entrypoint=self.entrypoint, hostname=hostname, port=port, verbose=verbose, gpio=args.gpio, name=args.name)
             self.unit.register(hostname, port, unit)
             return True
         else:
